cdn

package module
v1.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2025 License: GPL-3.0 Imports: 2 Imported by: 21

README

cdn

Open in Gitpod Open in Gitpod

tests Go Report Card PkgGoDev

Easy to use CDN URLs for using in Golang web UIs

If you want faster loading, reliability, and total security consider using UNCDN (https://github.com/gouniverse/uncdn)

Customizing CDN URL Prefix

The CDN_URL_PREFIX feature allows you to specify a custom CDN URL prefix via an environment variable. This can be useful if you want to use a different CDN for serving your assets.

To use the CDN_URL_PREFIX feature, set the CDN_URL_PREFIX environment variable to your desired CDN URL prefix. For example:

export CDN_URL_PREFIX="https://mycustomcdn.com/"

If the CDN_URL_PREFIX environment variable is set, it will be used as the base URL for the CDN; otherwise, the original CDN URL will be used.

Available methods

AlpineJS
  • AlpineJs_3_13_0 - latest
  • AlpineJs_3_12_3
AnimatedCSS
  • AnimatedCSS_4_1_1 - latest
Bootstrap
  • BootstrapCss_5_3_3() - latest

  • BootstrapJs_5_3_3()

  • BootstrapCosmoCss_5_3_3() // + all the Bottswatch themes for 5.3.3

  • BootstrapCss_5_3_2()

  • BootstrapJs_5_3_3()

  • BootstrapCosmoCss_5_3_2() // + all the Bottswatch themes for 5.3.1

  • BootstrapCss_5_3_1()

  • BootstrapJs_5_3_1()

  • BootstrapCosmoCss_5_3_1() // + all the Bottswatch themes for 5.3.1

  • BootstrapCss_5_3_0()

  • BootstrapJs_5_3_0()

  • BootstrapCosmoCss_5_3_0() // + all the Bottswatch themes for 5.3.0

  • BootstrapCss_5_2_3()

  • BootstrapJs_5_2_3()

Bootstrap Icons
  • BootstrapIconsCss_1_11_3() - latest

  • BootstrapIconsCss_1_11_2()

  • BootstrapIconsCss_1_11_0()

  • BootstrapIconsCss_1_10_5()

  • BootstrapIconsCss_1_10_2()

  • BootstrapIconsCss_1_9_1()

  • ChartsCss_0_9_3()

  • FontAwesomeCss_6_4_2() - latest

  • FontAwesomeCss_6_1_2()

GoogleFont
  • GoogleFont(family string, weight string)

Example:

cdn.GoogleFont("Josefin Sans", "300,400,500")
HTMX
  • Htmx_2_0_0() - latest
  • Htmx_1_9_9()
  • Htmx_1_9_6()
  • Htmx_1_9_5()
  • Htmx_1_9_4()
  • Htmx_1_9_2()
JQuery
  • Jquery_3_7_1() - latest
  • Jquery_3_6_4()
JQuery DataTables
  • JqueryDataTablesCss_1_13_4()
  • JqueryDataTablesJs_1_13_4()
JQTree
  • JqTreeCss_1_8_0()
  • JqTreeJs_1_8_0()
  • JqTreeCss_1_7_0()
  • JqTreeJs_1_7_0()
Notify
  • Notify_0_4_2()
SweetAlert v2
  • Sweetalert2_11() - latest
  • Sweetalert2_10()
Tailwind
  • TailwindCss_3_4_4() - latest
  • TailwindCss_3_3_3()
Trumbowyg
  • TrumbowygCss_2_27_3()
  • TrumbowygJs_2_27_3()
VueJS
  • VueJs_3()
  • VueElementPlusCss_2_3_8()
  • VueElementPlusJs_2_3_8()
  • VueTrumbowyg_4_0_0()

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AnimatedCSS_4_1_1 added in v1.8.0

func AnimatedCSS_4_1_1() string

func BootstrapCeruleanCss_5_3_0 added in v1.8.0

func BootstrapCeruleanCss_5_3_0() string

func BootstrapCeruleanCss_5_3_1 added in v1.8.0

func BootstrapCeruleanCss_5_3_1() string

func BootstrapCeruleanCss_5_3_3 added in v1.8.0

func BootstrapCeruleanCss_5_3_3() string

func BootstrapCosmoCss_5_3_0 added in v1.8.0

func BootstrapCosmoCss_5_3_0() string

func BootstrapCosmoCss_5_3_1 added in v1.8.0

func BootstrapCosmoCss_5_3_1() string

func BootstrapCosmoCss_5_3_3 added in v1.8.0

func BootstrapCosmoCss_5_3_3() string

func BootstrapCss_5_2_3 added in v1.8.0

func BootstrapCss_5_2_3() string

func BootstrapCss_5_3_0 added in v1.8.0

func BootstrapCss_5_3_0() string

func BootstrapCss_5_3_1 added in v1.8.0

func BootstrapCss_5_3_1() string

func BootstrapCss_5_3_2 added in v1.8.0

func BootstrapCss_5_3_2() string

======================= version 5.3.2 ======================= //

func BootstrapCss_5_3_3 added in v1.8.0

func BootstrapCss_5_3_3() string

======================= version 5.3.3 ======================= //

func BootstrapCss_5_3_7 added in v1.8.0

func BootstrapCss_5_3_7() string

======================= version 5.3.7 ======================= //

func BootstrapCss_5_3_8 added in v1.9.0

func BootstrapCss_5_3_8() string

======================= version 5.3.7 ======================= //

func BootstrapCyborgCss_5_3_0 added in v1.8.0

func BootstrapCyborgCss_5_3_0() string

func BootstrapCyborgCss_5_3_1 added in v1.8.0

func BootstrapCyborgCss_5_3_1() string

func BootstrapCyborgCss_5_3_3 added in v1.8.0

func BootstrapCyborgCss_5_3_3() string

func BootstrapDarklyCss_5_3_0 added in v1.8.0

func BootstrapDarklyCss_5_3_0() string

func BootstrapDarklyCss_5_3_1 added in v1.8.0

func BootstrapDarklyCss_5_3_1() string

func BootstrapDarklyCss_5_3_3 added in v1.8.0

func BootstrapDarklyCss_5_3_3() string

func BootstrapFlatlyCss_5_3_0 added in v1.8.0

func BootstrapFlatlyCss_5_3_0() string

func BootstrapFlatlyCss_5_3_1 added in v1.8.0

func BootstrapFlatlyCss_5_3_1() string

func BootstrapFlatlyCss_5_3_3 added in v1.8.0

func BootstrapFlatlyCss_5_3_3() string

func BootstrapIconsCss_1_9_1 added in v1.8.0

func BootstrapIconsCss_1_9_1() string

func BootstrapIconsCss_1_10_2 added in v1.8.0

func BootstrapIconsCss_1_10_2() string

func BootstrapIconsCss_1_10_5 added in v1.8.0

func BootstrapIconsCss_1_10_5() string

func BootstrapIconsCss_1_11_0 added in v1.8.0

func BootstrapIconsCss_1_11_0() string

func BootstrapIconsCss_1_11_2 added in v1.8.0

func BootstrapIconsCss_1_11_2() string

func BootstrapIconsCss_1_11_3 added in v1.8.0

func BootstrapIconsCss_1_11_3() string

func BootstrapIconsCss_1_13_1 added in v1.8.0

func BootstrapIconsCss_1_13_1() string

func BootstrapJournalCss_5_3_0 added in v1.8.0

func BootstrapJournalCss_5_3_0() string

func BootstrapJournalCss_5_3_1 added in v1.8.0

func BootstrapJournalCss_5_3_1() string

func BootstrapJournalCss_5_3_3 added in v1.8.0

func BootstrapJournalCss_5_3_3() string

func BootstrapJs_5_2_3 added in v1.8.0

func BootstrapJs_5_2_3() string

func BootstrapJs_5_3_0 added in v1.8.0

func BootstrapJs_5_3_0() string

func BootstrapJs_5_3_1 added in v1.8.0

func BootstrapJs_5_3_1() string

func BootstrapJs_5_3_2 added in v1.8.0

func BootstrapJs_5_3_2() string

func BootstrapJs_5_3_3 added in v1.8.0

func BootstrapJs_5_3_3() string

func BootstrapJs_5_3_7 added in v1.8.0

func BootstrapJs_5_3_7() string

func BootstrapJs_5_3_8 added in v1.9.0

func BootstrapJs_5_3_8() string

func BootstrapLiteraCss_5_3_0 added in v1.8.0

func BootstrapLiteraCss_5_3_0() string

func BootstrapLiteraCss_5_3_1 added in v1.8.0

func BootstrapLiteraCss_5_3_1() string

func BootstrapLiteraCss_5_3_3 added in v1.8.0

func BootstrapLiteraCss_5_3_3() string

func BootstrapLumenCss_5_3_0 added in v1.8.0

func BootstrapLumenCss_5_3_0() string

func BootstrapLumenCss_5_3_1 added in v1.8.0

func BootstrapLumenCss_5_3_1() string

func BootstrapLumenCss_5_3_3 added in v1.8.0

func BootstrapLumenCss_5_3_3() string

func BootstrapLuxCss_5_3_0 added in v1.8.0

func BootstrapLuxCss_5_3_0() string

func BootstrapLuxCss_5_3_1 added in v1.8.0

func BootstrapLuxCss_5_3_1() string

func BootstrapLuxCss_5_3_3 added in v1.8.0

func BootstrapLuxCss_5_3_3() string

func BootstrapMateriaCss_5_3_0 added in v1.8.0

func BootstrapMateriaCss_5_3_0() string

func BootstrapMateriaCss_5_3_1 added in v1.8.0

func BootstrapMateriaCss_5_3_1() string

func BootstrapMateriaCss_5_3_3 added in v1.8.0

func BootstrapMateriaCss_5_3_3() string

func BootstrapMintyCss_5_3_0 added in v1.8.0

func BootstrapMintyCss_5_3_0() string

func BootstrapMintyCss_5_3_1 added in v1.8.0

func BootstrapMintyCss_5_3_1() string

func BootstrapMintyCss_5_3_3 added in v1.8.0

func BootstrapMintyCss_5_3_3() string

func BootstrapMorphCss_5_3_0 added in v1.8.0

func BootstrapMorphCss_5_3_0() string

func BootstrapMorphCss_5_3_1 added in v1.8.0

func BootstrapMorphCss_5_3_1() string

func BootstrapMorphCss_5_3_3 added in v1.8.0

func BootstrapMorphCss_5_3_3() string

func BootstrapPulseCss_5_3_0 added in v1.8.0

func BootstrapPulseCss_5_3_0() string

func BootstrapPulseCss_5_3_1 added in v1.8.0

func BootstrapPulseCss_5_3_1() string

func BootstrapPulseCss_5_3_3 added in v1.8.0

func BootstrapPulseCss_5_3_3() string

func BootstrapQuartzCss_5_3_0 added in v1.8.0

func BootstrapQuartzCss_5_3_0() string

func BootstrapQuartzCss_5_3_1 added in v1.8.0

func BootstrapQuartzCss_5_3_1() string

func BootstrapQuartzCss_5_3_3 added in v1.8.0

func BootstrapQuartzCss_5_3_3() string

func BootstrapSandstoneCss_5_3_0 added in v1.8.0

func BootstrapSandstoneCss_5_3_0() string

func BootstrapSandstoneCss_5_3_1 added in v1.8.0

func BootstrapSandstoneCss_5_3_1() string

func BootstrapSandstoneCss_5_3_3 added in v1.8.0

func BootstrapSandstoneCss_5_3_3() string

func BootstrapSimplexCss_5_3_0 added in v1.8.0

func BootstrapSimplexCss_5_3_0() string

func BootstrapSimplexCss_5_3_1 added in v1.8.0

func BootstrapSimplexCss_5_3_1() string

func BootstrapSimplexCss_5_3_3 added in v1.8.0

func BootstrapSimplexCss_5_3_3() string

func BootstrapSketchyCss_5_3_0 added in v1.8.0

func BootstrapSketchyCss_5_3_0() string

func BootstrapSketchyCss_5_3_1 added in v1.8.0

func BootstrapSketchyCss_5_3_1() string

func BootstrapSketchyCss_5_3_3 added in v1.8.0

func BootstrapSketchyCss_5_3_3() string

func BootstrapSlateCss_5_3_0 added in v1.8.0

func BootstrapSlateCss_5_3_0() string

func BootstrapSlateCss_5_3_1 added in v1.8.0

func BootstrapSlateCss_5_3_1() string

func BootstrapSlateCss_5_3_3 added in v1.8.0

func BootstrapSlateCss_5_3_3() string

func BootstrapSolarCss_5_3_0 added in v1.8.0

func BootstrapSolarCss_5_3_0() string

func BootstrapSolarCss_5_3_1 added in v1.8.0

func BootstrapSolarCss_5_3_1() string

func BootstrapSolarCss_5_3_3 added in v1.8.0

func BootstrapSolarCss_5_3_3() string

func BootstrapSpacelabCss_5_3_0 added in v1.8.0

func BootstrapSpacelabCss_5_3_0() string

func BootstrapSpacelabCss_5_3_1 added in v1.8.0

func BootstrapSpacelabCss_5_3_1() string

func BootstrapSpacelabCss_5_3_3 added in v1.8.0

func BootstrapSpacelabCss_5_3_3() string

func BootstrapSuperheroCss_5_3_0 added in v1.8.0

func BootstrapSuperheroCss_5_3_0() string

func BootstrapSuperheroCss_5_3_1 added in v1.8.0

func BootstrapSuperheroCss_5_3_1() string

func BootstrapSuperheroCss_5_3_3 added in v1.8.0

func BootstrapSuperheroCss_5_3_3() string

func BootstrapUnitedCss_5_3_0 added in v1.8.0

func BootstrapUnitedCss_5_3_0() string

func BootstrapUnitedCss_5_3_1 added in v1.8.0

func BootstrapUnitedCss_5_3_1() string

func BootstrapUnitedCss_5_3_3 added in v1.8.0

func BootstrapUnitedCss_5_3_3() string

func BootstrapVaporCss_5_3_0 added in v1.8.0

func BootstrapVaporCss_5_3_0() string

func BootstrapVaporCss_5_3_1 added in v1.8.0

func BootstrapVaporCss_5_3_1() string

func BootstrapVaporCss_5_3_3 added in v1.8.0

func BootstrapVaporCss_5_3_3() string

func BootstrapYetiCss_5_3_0 added in v1.8.0

func BootstrapYetiCss_5_3_0() string

func BootstrapYetiCss_5_3_1 added in v1.8.0

func BootstrapYetiCss_5_3_1() string

func BootstrapYetiCss_5_3_3 added in v1.8.0

func BootstrapYetiCss_5_3_3() string

func BootstrapZephyrCss_5_3_0 added in v1.8.0

func BootstrapZephyrCss_5_3_0() string

func BootstrapZephyrCss_5_3_1 added in v1.8.0

func BootstrapZephyrCss_5_3_1() string

func BootstrapZephyrCss_5_3_3 added in v1.8.0

func BootstrapZephyrCss_5_3_3() string

func ChartsCss_0_9_3 added in v1.8.0

func ChartsCss_0_9_3() string

func ChartsCss_1_1_0 added in v1.8.0

func ChartsCss_1_1_0() string

func FontAwesomeCss_6_1_2 added in v1.8.0

func FontAwesomeCss_6_1_2() string

func FontAwesomeCss_6_4_2 added in v1.8.0

func FontAwesomeCss_6_4_2() string

func FontAwesomeCss_6_5_2 added in v1.8.0

func FontAwesomeCss_6_5_2() string

func GoogleFont added in v1.8.0

func GoogleFont(family string, weight string) string

func Htmx_1_9_2 added in v1.8.0

func Htmx_1_9_2() string

func Htmx_1_9_4 added in v1.8.0

func Htmx_1_9_4() string

func Htmx_1_9_5 added in v1.8.0

func Htmx_1_9_5() string

func Htmx_1_9_6 added in v1.8.0

func Htmx_1_9_6() string

func Htmx_1_9_9 added in v1.8.0

func Htmx_1_9_9() string

func Htmx_1_9_11 added in v1.8.0

func Htmx_1_9_11() string

func Htmx_2_0_0 added in v1.8.0

func Htmx_2_0_0() string

func JqTreeCss_1_7_0 added in v1.8.0

func JqTreeCss_1_7_0() string

func JqTreeCss_1_8_0 added in v1.8.0

func JqTreeCss_1_8_0() string

func JqTreeCss_1_8_2 added in v1.8.0

func JqTreeCss_1_8_2() string

func JqTreeCss_1_8_3 added in v1.8.0

func JqTreeCss_1_8_3() string

func JqTreeJs_1_7_0 added in v1.8.0

func JqTreeJs_1_7_0() string

func JqTreeJs_1_8_0 added in v1.8.0

func JqTreeJs_1_8_0() string

func JqTreeJs_1_8_2 added in v1.8.0

func JqTreeJs_1_8_2() string

func JqTreeJs_1_8_3 added in v1.8.0

func JqTreeJs_1_8_3() string

func JqueryDataTablesCss_1_13_4 added in v1.8.0

func JqueryDataTablesCss_1_13_4() string

func JqueryDataTablesCss_2_2_2 added in v1.8.0

func JqueryDataTablesCss_2_2_2() string

func JqueryDataTablesJs_1_13_4 added in v1.8.0

func JqueryDataTablesJs_1_13_4() string

func JqueryDataTablesJs_2_2_2 added in v1.8.0

func JqueryDataTablesJs_2_2_2() string

func JqueryUiCss_1_13_1 added in v1.8.0

func JqueryUiCss_1_13_1() string

func JqueryUiJs_1_13_1 added in v1.8.0

func JqueryUiJs_1_13_1() string

func Jquery_3_6_4 added in v1.8.0

func Jquery_3_6_4() string

func Jquery_3_7_1 added in v1.8.0

func Jquery_3_7_1() string

func Notify_0_4_2 added in v1.8.0

func Notify_0_4_2() string

func Sweetalert2_10 added in v1.8.0

func Sweetalert2_10() string

func Sweetalert2_11 added in v1.8.0

func Sweetalert2_11() string

func TailwindCss_3_3_3 added in v1.8.0

func TailwindCss_3_3_3() string

func TailwindCss_3_4_4 added in v1.8.0

func TailwindCss_3_4_4() string

func TailwindCss_Browser_4 added in v1.8.0

func TailwindCss_Browser_4() string

func TrumbowygCss_2_27_3 added in v1.8.0

func TrumbowygCss_2_27_3() string

func TrumbowygJs_2_27_3 added in v1.8.0

func TrumbowygJs_2_27_3() string

func VueElementPlusCss_2_3_8 added in v1.8.0

func VueElementPlusCss_2_3_8() string

func VueElementPlusJs_2_3_8 added in v1.8.0

func VueElementPlusJs_2_3_8() string

func VueJs_3 added in v1.8.0

func VueJs_3() string

func VueTrumbowyg_4_0_0 added in v1.8.0

func VueTrumbowyg_4_0_0() string

Types

This section is empty.

Jump to